---
sidebar_position: 3
---

# LLDFModel class

This class models the output data from the LLDF operation.

## Syntax

```python
LLDFModel(x_data: pd.DataFrame, x_train: pd.DataFrame, y: pd.DataFrame)
```

## Fields and constructor parameters

All three are `Pandas` `DataFrame` objects:
- `x_data`
- `x_train`
- `y`


